<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\Auth;
use App\Models\RechargeApi;
use Log;

class CustomerController extends Controller {

    private $rechargeApi;
    private $shop;

    public function __construct() {

        $this->rechargeApi = new RechargeApi(); 
        //$shop = Auth::user();
    }

    public function home() {

        return view('welcome');
    }

    /**
     * Get primary customer account details
     */
    public function getCustomerDetails(Request $request) {

        $errorMessage = '';
        $emailAddress = '';
        $customerHash = '';
        $responseData = [];
        $customerId = !empty($request->get('id')) ? $request->get('id') : '';
        if (empty($customerId)) {

            $errorMessage = 'Failed to get the customer details from Recharge';
            $error = "Failed to get the customerId from the URL";
            Log::channel('customerPortalUrlCreationLog')->info($error);
            return view('customer',compact('errorMessage'));
        }

        $customerDetails = $this->rechargeApi->getCustomerDetailsByShopifyCustomerId($customerId);
        if (!empty($customerDetails->error) || !empty($customerDetails->errors) || 
        empty($customerDetails) || empty($customerDetails->customers)) {

            // Log Entry
            $error  = "Unknown error";
            if (!empty($customerDetails->error)) {

                $error = $customerDetails->error;

            } else if (!empty($customerDetails->errors)) {

                $error = json_encode($customerDetails->errors);
            } else if (empty($customerDetails) || empty($customerDetails->customers)) {

                $error = 'Empty response from the API';
            }
            $errorMessage = 'Not found the customer in recharge';
            $rechargeError = "Failed to get the customer details from Recharge - Error: ".$error;
            Log::channel('customerPortalUrlCreationLog')->info(
                "Failed to get the customer details from recharge, (ShopifyCustomerId: ".$customerId.", 
                Error: ".$rechargeError
            );
            $responseData = [
                "email" => '',
                "hash" => '',
                "errorMessage" => $errorMessage
            ];
            return view('customer',compact('responseData'));
        }
        $emailAddress = $customerDetails->customers[0]->email;
        $customerHash = $customerDetails->customers[0]->hash;

        $responseData = [
            "email" => $emailAddress,
            "hash" => $customerHash,
            "errorMessage" => ''
        ];

        Log::channel('customerPortalUrlCreationLog')->info("Successfully got the customer recharge details, 
        (rechargeData: ".json_encode($responseData));

        return view('customer',compact('responseData'));
    }

}
